( cd usr/include/gphoto2 ; rm -rf gphoto2 )
( cd usr/include/gphoto2 ; ln -sf . gphoto2 )
( cd usr/lib ; rm -rf libgphoto2.so.2 )
( cd usr/lib ; ln -sf libgphoto2.so.2.4.0 libgphoto2.so.2 )
( cd usr/lib ; rm -rf libgphoto2_port.so )
( cd usr/lib ; ln -sf libgphoto2_port.so.0.8.0 libgphoto2_port.so )
( cd usr/lib ; rm -rf libgphoto2.so )
( cd usr/lib ; ln -sf libgphoto2.so.2.4.0 libgphoto2.so )
( cd usr/lib ; rm -rf libgphoto2_port.so.0 )
( cd usr/lib ; ln -sf libgphoto2_port.so.0.8.0 libgphoto2_port.so.0 )
